pub(crate) enum CssPropertyName {
BackgroundColor,
FontSize,
FontWeight,
FontStyle,
TextDecorationLine,
}Expand description
Variants
Implementations
Sourceimpl CssPropertyName
impl CssPropertyName
fn resolved_value_for_node(&self, element: &Element) -> Option<DOMString>
Sourcepub(crate) fn value_set_for_style(&self, element: &Element) -> Option<DOMString>
pub(crate) fn value_set_for_style(&self, element: &Element) -> Option<DOMString>
Retrieves a respective css longhand value from the style declarations of an element. Note that this is different than the computed values, since this is only relevant when the author specified rules on the specific element.
fn property_name(&self) -> DOMString
pub(crate) fn set_for_element( &self, cx: &mut JSContext, element: &HTMLElement, new_value: DOMString, )
pub(crate) fn remove_from_element( &self, cx: &mut JSContext, element: &HTMLElement, )
pub(crate) fn value_for_element( &self, cx: &mut JSContext, element: &HTMLElement, ) -> DOMString